`conv start`

`example_user`
2x + 3 = x

`example_assistant`
2x + 3 - x = x - x
[END]

`example_user`
(2x - x) + 3 = 0

`example_assistant`
x + 3 = 0
[END]


`example_user`
5x + 3x - 2x = 0

`example_assistant`
(5x + 3x) - 2x = 0
[END]

`example_user`
(5x + 3x) - 2x = 0

`example_assistant`
8x - 2x = 0
[END]

`example_user`
8x - 2x = 0

`example_assistant`
6x = 0
[END]

`example_user`
6x = 0

`example_assistant`
6x / 6 = 0 / 6
[END]

`example_user`
6x / 6 = 0 / 6

`example_assistant`
x = 0
[END]

`conv end`